class Management::ObjectTypesController < ManagementController
  before_action :set_management_object_type, only: [:edit, :update, :destroy]
  before_action :get_mime_types, only: [:new, :edit]

  # GET /management/object_types
  # GET /management/object_types.json
  def index
    @object_types = ::ObjectType.includes(:mime_types).all
  end

  # GET /management/object_types/new
  def new
    @object_type = ::ObjectType.new
    @selected = []
  end

  # GET /management/object_types/1/edit
  def edit
    @selected = @object_type.mime_types.map { |mime_type| mime_type.id }
  end


  # POST /management/object_types
  # POST /management/object_types.json
  def create
    @object_type = ::ObjectType.new(sanitazed_params)

    respond_to do |format|
      if @object_type.save
        format.html { redirect_to management_object_types_path, notice: 'Tipo de objeto criado com sucesso.' }
        format.json { render :show, status: :created, location: management_object_types_path }
      else
        format.html { render :new }
        format.json { render json: @object_type.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /management/object_types/1
  # PATCH/PUT /management/object_types/1.json
  def update
    respond_to do |format|
      if @object_type.update(sanitazed_params)
        format.html { redirect_to management_object_types_path, notice: 'Tipo de objeto atualizado com sucesso.' }
        format.json { render :show, status: :ok, location: management_object_types_path }
      else
        format.html { render :edit }
        format.json { render json: @object_type.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /management/object_types/1
  # DELETE /management/object_types/1.json
  def destroy
    SafeObjectTypeDestroyService.execute @object_type
    respond_to do |format|
      format.html { redirect_to management_object_types_url, notice: 'Tipo de objeto destruido com sucesso.' }
      format.json { head :no_content }
    end
  end

  private

  # Get all the mime types
  def get_mime_types
    @mime_types = MimeType.all
  end
  # Use callbacks to share common setup or constraints between actions.
  def set_management_object_type
    @object_type = ObjectType.find(params[:id])
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def object_type_params
    params.require(:object_type).permit(:name, mime_types: [])
  end

  # Build mimetypes
  def sanitazed_params
    _params = object_type_params
    _params[:mime_types] = []
    unless object_type_params[:mime_types].blank?
      object_type_params[:mime_types].each do |mime_type|
        _params[:mime_types] << MimeType.find(mime_type)
      end
    end
    _params
  end
end
